searchData={"items":[{"type":"module","title":"Lume","doc":"Lume is a simple, modern UI component library for Phoenix LiveView.","ref":"Lume.html"},{"type":"module","title":"Lume.ComponentBase","doc":"Base module for Lume components.\n\nProvides common configuration for Phoenix.Component and Gettext.","ref":"Lume.ComponentBase.html"},{"type":"module","title":"Lume.Components.Avatar","doc":"A simple avatar component that displays either an image or fallback initials.","ref":"Lume.Components.Avatar.html"},{"type":"module","title":"Features - Lume.Components.Avatar","doc":"* Supports image avatars with fallback to initials\n  * Multiple sizes (small, medium, large)\n  * Shape variants (circle or rounded square)\n  * Optional status indicator dot\n  * Dark mode support\n  * Automatic error handling for failed image loads\n  * Customizable fallback colors","ref":"Lume.Components.Avatar.html#module-features"},{"type":"module","title":"Examples - Lume.Components.Avatar","doc":"<.avatar\n      alt=\"John Doe\"\n      fallback=\"JD\"\n      size={:md}\n      image_url=\"path/to/image.jpg\"\n    />\n\n    # With status indicator\n    <.avatar\n      alt=\"Alan B\"\n      fallback=\"AB\"\n      show_dot\n      dot_variant={:success}\n    />\n\n    # Custom fallback colors\n    <.avatar\n      alt=\"User\"\n      fallback=\"U\"\n      fallback_class=\"bg-indigo-100 text-indigo-600\"\n    />\n\n    # Square variant with custom size\n    <.avatar\n      alt=\"User\"\n      fallback=\"U\"\n      shape={:square}\n      class=\"h-16 w-16\"\n    />","ref":"Lume.Components.Avatar.html#module-examples"},{"type":"function","title":"Lume.Components.Avatar.avatar/1","doc":"Renders an avatar component.","ref":"Lume.Components.Avatar.html#avatar/1"},{"type":"function","title":"Attributes - Lume.Components.Avatar.avatar/1","doc":"* `image_url` - Optional URL to the avatar image\n  * `alt` - Required alt text for the avatar\n  * `fallback` - Required text to display when image is missing or loading fails\n  * `fallback_class` - Custom classes for fallback background and text colors\n  * `size` - Size variant (`:sm`, `:md`, `:lg`), defaults to `:md`\n  * `shape` - Shape variant (`:circle`, `:square`), defaults to `:circle`\n  * `show_dot` - Whether to show a status dot indicator\n  * `dot_variant` - Status dot color variant, defaults to `:success`\n  * `class` - Additional CSS classes to apply to the avatar","ref":"Lume.Components.Avatar.html#avatar/1-attributes"},{"type":"function","title":"Attributes - Lume.Components.Avatar.avatar/1","doc":"* `image_url` (`:string`) - Defaults to `nil`.\n* `alt` (`:string`) (required)\n* `fallback` (`:string`) (required)\n* `fallback_class` (`:string`) - Defaults to `\"bg-gray-200 text-gray-900\"`.\n* `size` (`:atom`) - Defaults to `:md`.\n* `shape` (`:atom`) - Defaults to `:circle`.\n* `show_dot` (`:boolean`) - Defaults to `false`.\n* `dot_variant` (`:atom`) - Defaults to `:success`.\n* `class` (`:string`) - Defaults to `nil`.","ref":"Lume.Components.Avatar.html#avatar/1-attributes"},{"type":"module","title":"Lume.Components.Badge","doc":"A simple badge component for status indicators, labels, and counts.","ref":"Lume.Components.Badge.html"},{"type":"module","title":"Features - Lume.Components.Badge","doc":"* Multiple color variants (default, primary, success, warning, error)\n  * Three sizes (small, medium, large)\n  * Shape options (pill or flat)\n  * Optional border styling\n  * Optional leading dot indicator\n  * Optional icon\n  * Dark mode support","ref":"Lume.Components.Badge.html#module-features"},{"type":"module","title":"Examples - Lume.Components.Badge","doc":"# Basic badge\n    <.badge>Default</.badge>\n\n    # Primary badge with icon\n    <.badge variant={:primary} icon=\"hero-star\">\n      Featured\n    </.badge>\n\n    # Success badge with dot indicator\n    <.badge variant={:success} show_dot>\n      Online\n    </.badge>\n\n    # Warning badge with flat shape and border\n    <.badge\n      variant={:warning}\n      shape={:flat}\n      bordered\n    >\n      Beta\n    </.badge>\n\n    # Large error badge with icon\n    <.badge\n      variant={:error}\n      size={:lg}\n      icon=\"hero-exclamation-circle\"\n    >\n      Critical\n    </.badge>","ref":"Lume.Components.Badge.html#module-examples"},{"type":"function","title":"Lume.Components.Badge.badge/1","doc":"Renders a badge component.","ref":"Lume.Components.Badge.html#badge/1"},{"type":"function","title":"Attributes - Lume.Components.Badge.badge/1","doc":"* `variant` - Color variant (`:default`, `:primary`, `:success`, `:warning`, `:error`), defaults to `:default`\n  * `size` - Size variant (`:sm`, `:md`, `:lg`), defaults to `:md`\n  * `shape` - Shape variant (`:pill`, `:flat`), defaults to `:pill`\n  * `bordered` - Whether to show a border matching the text color, defaults to `false`\n  * `show_dot` - Whether to show a leading dot indicator, defaults to `false`\n  * `icon` - Optional icon name (from heroicons)\n  * `class` - Additional CSS classes to apply to the badge","ref":"Lume.Components.Badge.html#badge/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Badge.badge/1","doc":"* `inner_block` - Required. The content to display inside the badge","ref":"Lume.Components.Badge.html#badge/1-slots"},{"type":"function","title":"Attributes - Lume.Components.Badge.badge/1","doc":"* `variant` (`:atom`) - Defaults to `:default`.\n* `size` (`:atom`) - Defaults to `:md`.\n* `shape` (`:atom`) - Defaults to `:pill`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* `icon` (`:string`) - Defaults to `nil`.\n* `show_dot` (`:boolean`) - Defaults to `false`.\n* `class` (`:string`) - Defaults to `nil`.","ref":"Lume.Components.Badge.html#badge/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Badge.badge/1","doc":"* `inner_block` (required)","ref":"Lume.Components.Badge.html#badge/1-slots"},{"type":"module","title":"Lume.Components.Breadcrumbs","doc":"","ref":"Lume.Components.Breadcrumbs.html"},{"type":"function","title":"Lume.Components.Breadcrumbs.breadcrumbs/1","doc":"A breadcrumbs component","ref":"Lume.Components.Breadcrumbs.html#breadcrumbs/1"},{"type":"function","title":"Examples - Lume.Components.Breadcrumbs.breadcrumbs/1","doc":"<.breadcrumbs id=\"item\">\n      <:crumb navigate={~p\"/\"}>\n        <.icon name=\"hero-home-mini\" class=\"w-4 h-4 mr-1\" /> Home\n      </:crumb>\n      <:crumb navigate={~p\"/items\"}>Items</:crumb>\n      <:crumb current={true}>Current Item</:crumb>\n    </.breadcrumbs>\n\n    <.breadcrumbs id=\"custom-separator\" separator_icon=\"hero-chevron-right-mini\">\n      <:crumb navigate={~p\"/\"}>Home</:crumb>\n      <:crumb navigate={~p\"/items\"}>Items</:crumb>\n      <:crumb>Item</:crumb>\n    </.breadcrumbs>","ref":"Lume.Components.Breadcrumbs.html#breadcrumbs/1-examples"},{"type":"function","title":"Attributes - Lume.Components.Breadcrumbs.breadcrumbs/1","doc":"* `id` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.\n* `separator_icon` (`:string`) - Defaults to `\"hero-chevron-right-mini\"`.\n* `size` (`:string`) - Defaults to `\"sm\"`.","ref":"Lume.Components.Breadcrumbs.html#breadcrumbs/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Breadcrumbs.breadcrumbs/1","doc":"* `crumb` (required) - Accepts attributes:\n\n  * `navigate` (`:string`)\n  * `current` (`:boolean`)","ref":"Lume.Components.Breadcrumbs.html#breadcrumbs/1-slots"},{"type":"module","title":"Lume.Components.Button","doc":"A versatile button component with multiple variants, sizes, and styling options.","ref":"Lume.Components.Button.html"},{"type":"module","title":"Features - Lume.Components.Button","doc":"* Multiple variants (primary, secondary, outline, minimal)\n  * Various sizes (xs, sm, md, lg, xl)\n  * Optional icon support\n  * Content justification options\n  * Border toggle for outline variant\n  * Focus and hover states","ref":"Lume.Components.Button.html#module-features"},{"type":"module","title":"Examples - Lume.Components.Button","doc":"# Basic button\n    <.button>Send!</.button>\n\n    # Button with Phoenix event\n    <.button phx-click=\"go\" class=\"ml-2\">Send!</.button>\n\n    # Button with leading icon\n    <.button icon=\"hero-user-group\">Teams</.button>\n\n    # Outline button without border\n    <.button variant=\"outline\" border={false}>Borderless</.button>\n\n    # Left-aligned full-width button\n    <.button justify=\"start\" class=\"w-full\">Left aligned</.button>\n\n    # Large secondary button\n    <.button variant=\"secondary\" size=\"lg\">Large Button</.button>","ref":"Lume.Components.Button.html#module-examples"},{"type":"function","title":"Lume.Components.Button.button/1","doc":"Renders a button component.","ref":"Lume.Components.Button.html#button/1"},{"type":"function","title":"Attributes - Lume.Components.Button.button/1","doc":"* `type` - HTML button type attribute, defaults to \"button\"\n  * `class` - Additional CSS classes to apply to the button\n  * `variant` - Button style variant (\"primary\", \"secondary\", \"outline\", \"minimal\"), defaults to \"primary\"\n  * `size` - Size variant (\"xs\", \"sm\", \"md\", \"lg\", \"xl\"), defaults to \"md\"\n  * `icon` - Optional icon name (from heroicons)\n  * `justify` - Content alignment (\"start\", \"center\", \"end\"), defaults to \"center\"\n  * `border` - Whether to show a border (only applies to outline variant), defaults to true","ref":"Lume.Components.Button.html#button/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Button.button/1","doc":"* `inner_block` - Required. The content to display inside the button","ref":"Lume.Components.Button.html#button/1-slots"},{"type":"function","title":"Attributes - Lume.Components.Button.button/1","doc":"* `type` (`:string`) - Defaults to `\"button\"`.\n* `class` (`:string`) - Defaults to `nil`.\n* `variant` (`:string`) - Defaults to `\"primary\"`.\n* `size` (`:string`) - Defaults to `\"md\"`.\n* `icon` (`:string`) - the name of the icon to display. Defaults to `nil`.\n* `justify` (`:string`) - content alignment (start=left, center, end=right). Defaults to `\"center\"`.\n* `border` (`:boolean`) - whether to show a border (applies to outline variant). Defaults to `true`.\n* Global attributes are accepted.","ref":"Lume.Components.Button.html#button/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Button.button/1","doc":"* `inner_block` (required)","ref":"Lume.Components.Button.html#button/1-slots"},{"type":"module","title":"Lume.Components.DropdownMenu","doc":"A flexible dropdown menu component with smooth transitions.","ref":"Lume.Components.DropdownMenu.html"},{"type":"module","title":"Features - Lume.Components.DropdownMenu","doc":"* Flexible trigger content (button, text, avatar, etc.)\n  * Menu items with optional icons and variants\n  * Smooth transitions using Phoenix.LiveView.JS\n  * Dark mode support\n  * Configurable dropdown alignment (left, right)\n  * Multiple size variants\n  * Click outside or escape key to close\n  * Support for right-aligned content in menu items","ref":"Lume.Components.DropdownMenu.html#module-features"},{"type":"module","title":"Basic Usage - Lume.Components.DropdownMenu","doc":"The dropdown menu can be used with a built-in trigger (icon + label) or with a custom trigger:\n\n```heex\n# With icon and label (disclosure indicator is shown by default)\n<.dropdown_menu id=\"user-menu\" icon=\"hero-user\" label=\"User Menu\">\n  <.menu_item>Profile</.menu_item>\n  <.menu_item>Settings</.menu_item>\n</.dropdown_menu>\n\n# Without disclosure indicator\n<.dropdown_menu id=\"menu\" icon=\"hero-cog-6-tooth\" label=\"Settings\" disclosure={false}>\n  <.menu_item>General</.menu_item>\n  <.menu_item>Advanced</.menu_item>\n</.dropdown_menu>\n\n# Or with a custom trigger\n<.dropdown_menu id=\"custom-trigger\">\n  <:trigger>\n     Custom Trigger \n  </:trigger>\n  <.menu_item>Profile</.menu_item>\n</.dropdown_menu>\n```","ref":"Lume.Components.DropdownMenu.html#module-basic-usage"},{"type":"module","title":"Menu Items - Lume.Components.DropdownMenu","doc":"Menu items support several features:","ref":"Lume.Components.DropdownMenu.html#module-menu-items"},{"type":"module","title":"Icons and Variants - Lume.Components.DropdownMenu","doc":"```heex\n<.dropdown_menu id=\"menu-with-variants\">\n  <.menu_item icon=\"hero-user\">\n    Profile\n  </.menu_item>\n  <.menu_item icon=\"hero-cog-6-tooth\" variant={:warning}>\n    Settings\n  </.menu_item>\n  <.menu_item icon=\"hero-arrow-right-on-rectangle\" variant={:danger}>\n    Sign out\n  </.menu_item>\n</.dropdown_menu>\n```","ref":"Lume.Components.DropdownMenu.html#module-icons-and-variants"},{"type":"module","title":"Right-aligned Content - Lume.Components.DropdownMenu","doc":"Perfect for displaying keyboard shortcuts or additional information:\n\n```heex\n<.dropdown_menu id=\"menu-with-shortcuts\">\n  <.menu_item icon=\"hero-magnifying-glass\">\n    Search\n    <:right_content>\n       ⌘K \n    </:right_content>\n  </.menu_item>\n  <.menu_item icon=\"hero-trash\" variant={:danger}>\n    Delete\n    <:right_content>\n       ⌘⌫ \n    </:right_content>\n  </.menu_item>\n</.dropdown_menu>\n```","ref":"Lume.Components.DropdownMenu.html#module-right-aligned-content"},{"type":"module","title":"Disabled Items - Lume.Components.DropdownMenu","doc":"```heex\n<.dropdown_menu id=\"menu-with-disabled\">\n  <.menu_item>Enabled Item</.menu_item>\n  <.menu_item disabled={true}>Disabled Item</.menu_item>\n</.dropdown_menu>\n```","ref":"Lume.Components.DropdownMenu.html#module-disabled-items"},{"type":"module","title":"Using Separators - Lume.Components.DropdownMenu","doc":"Use the separator component to group related items:\n\n```heex\n<.dropdown_menu id=\"menu-with-separator\">\n  <.menu_item icon=\"hero-user\">Profile</.menu_item>\n  <.menu_item icon=\"hero-cog-6-tooth\">Settings</.menu_item>\n  <.separator />\n  <.menu_item icon=\"hero-arrow-right-on-rectangle\" variant={:danger}>\n    Sign out\n  </.menu_item>\n</.dropdown_menu>\n```","ref":"Lume.Components.DropdownMenu.html#module-using-separators"},{"type":"module","title":"Customization - Lume.Components.DropdownMenu","doc":"","ref":"Lume.Components.DropdownMenu.html#module-customization"},{"type":"module","title":"Size Variants - Lume.Components.DropdownMenu","doc":"Both the trigger and menu items can be sized independently:\n\n```heex\n<.dropdown_menu id=\"large-menu\" size={:lg} menu_size={:lg}>\n  <.menu_item size={:lg}>Large Item</.menu_item>\n</.dropdown_menu>\n```\n\nAvailable sizes:\n- `:sm` - Compact size\n- `:md` - Default size\n- `:lg` - Large size","ref":"Lume.Components.DropdownMenu.html#module-size-variants"},{"type":"module","title":"Menu Alignment - Lume.Components.DropdownMenu","doc":"Control which side the menu appears on:\n\n```heex\n<.dropdown_menu id=\"right-menu\" align={:right}>\n  <.menu_item>Right-aligned Menu</.menu_item>\n</.dropdown_menu>\n```","ref":"Lume.Components.DropdownMenu.html#module-menu-alignment"},{"type":"module","title":"Accessibility - Lume.Components.DropdownMenu","doc":"The dropdown menu implements several accessibility features:\n- Keyboard navigation (Tab, Enter, Space, Escape)\n- ARIA roles and attributes\n- Focus management\n- Screen reader support","ref":"Lume.Components.DropdownMenu.html#module-accessibility"},{"type":"function","title":"Lume.Components.DropdownMenu.dropdown_menu/1","doc":"Renders a dropdown menu component.","ref":"Lume.Components.DropdownMenu.html#dropdown_menu/1"},{"type":"function","title":"Attributes - Lume.Components.DropdownMenu.dropdown_menu/1","doc":"* `id` - Required unique identifier for the dropdown\n  * `label` - Optional text label for the trigger (replaces the trigger slot)\n  * `icon` - Optional icon name to display (replaces the trigger slot)\n  * `disclosure` - Whether to show a disclosure indicator in the trigger, defaults to true\n  * `align` - Alignment of the menu (`:left` or `:right`), defaults to `:left`\n  * `size` - Size variant for the trigger label and icons (`:sm`, `:md`, `:lg`), defaults to `:md`\n  * `menu_size` - Size variant for the menu width (`:sm`, `:md`, `:lg`), defaults to `:md`\n  * `class` - Additional CSS classes to apply to the trigger container\n  * `menu_class` - Additional CSS classes to apply to the menu container","ref":"Lume.Components.DropdownMenu.html#dropdown_menu/1-attributes"},{"type":"function","title":"Slots - Lume.Components.DropdownMenu.dropdown_menu/1","doc":"* `trigger` - The content that triggers the dropdown menu (overrides label and icon)\n  * `inner_block` - The content of the dropdown menu (typically menu_item components)","ref":"Lume.Components.DropdownMenu.html#dropdown_menu/1-slots"},{"type":"function","title":"Examples - Lume.Components.DropdownMenu.dropdown_menu/1","doc":"<.dropdown_menu\n      id=\"user-menu\"\n      icon=\"hero-user\"\n      label=\"User Menu\"\n      menu_size={:lg}\n    >\n      <.menu_item>\n        <.link navigate={~p\"/profile\"} class=\"w-full\">Profile</.link>\n      </.menu_item>\n      <.menu_item>\n        <.link patch={~p\"/settings\"} class=\"w-full\">Settings</.link>\n      </.menu_item>\n      <.menu_item variant={:danger}>\n         Sign out \n      </.menu_item>\n    </.dropdown_menu>","ref":"Lume.Components.DropdownMenu.html#dropdown_menu/1-examples"},{"type":"function","title":"Attributes - Lume.Components.DropdownMenu.dropdown_menu/1","doc":"* `id` (`:string`) (required)\n* `label` (`:string`) - Defaults to `nil`.\n* `icon` (`:string`) - Defaults to `nil`.\n* `disclosure` (`:boolean`) - Defaults to `true`.\n* `align` (`:atom`) - Defaults to `:left`.\n* `size` (`:atom`) - Defaults to `:md`.\n* `menu_size` (`:atom`) - Defaults to `:md`.\n* `class` (`:string`) - Defaults to `nil`.\n* `menu_class` (`:string`) - Defaults to `nil`.","ref":"Lume.Components.DropdownMenu.html#dropdown_menu/1-attributes"},{"type":"function","title":"Slots - Lume.Components.DropdownMenu.dropdown_menu/1","doc":"* `trigger`\n* `inner_block` (required)","ref":"Lume.Components.DropdownMenu.html#dropdown_menu/1-slots"},{"type":"function","title":"Lume.Components.DropdownMenu.hide_menu/1","doc":"Hides the dropdown menu.","ref":"Lume.Components.DropdownMenu.html#hide_menu/1"},{"type":"function","title":"Lume.Components.DropdownMenu.menu_item/1","doc":"Renders a menu item within a dropdown menu.","ref":"Lume.Components.DropdownMenu.html#menu_item/1"},{"type":"function","title":"Attributes - Lume.Components.DropdownMenu.menu_item/1","doc":"* `variant` - Optional color variant (`:default`, `:danger`, or `:warning`)\n  * `disabled` - Optional boolean to disable the item\n  * `icon` - Optional icon name to display\n  * `class` - Additional CSS classes for the menu item\n  * `href` - Optional URL for traditional browser navigation\n  * `navigate` - Optional path for LiveView navigation\n  * `patch` - Optional path for LiveView patching\n  * `replace` - Optional boolean to replace browser history when using navigate or patch\n  * `method` - Optional HTTP method to use with href (e.g., \"delete\", \"post\")\n  * `csrf_token` - Optional CSRF token for non-GET requests (defaults to true)\n  * `rest` - Any additional HTML attributes","ref":"Lume.Components.DropdownMenu.html#menu_item/1-attributes"},{"type":"function","title":"Slots - Lume.Components.DropdownMenu.menu_item/1","doc":"* `right_content` - Content to display on the right side of the menu item\n  * `inner_block` - The content of the menu item","ref":"Lume.Components.DropdownMenu.html#menu_item/1-slots"},{"type":"function","title":"Examples - Lume.Components.DropdownMenu.menu_item/1","doc":"<.menu_item variant={:danger} icon=\"hero-trash\">\n      Delete\n      <:right_content>\n         ⌘D \n      </:right_content>\n    </.menu_item>\n\n    <.menu_item href=\"/profile\" icon=\"hero-user\">\n      View Profile\n    </.menu_item>\n\n    <.menu_item navigate={~p\"/settings\"} icon=\"hero-cog-6-tooth\">\n      Settings\n    </.menu_item>\n\n    <.menu_item href={~p\"/posts/1\"} method=\"delete\" icon=\"hero-trash\">\n      Delete Post\n    </.menu_item>","ref":"Lume.Components.DropdownMenu.html#menu_item/1-examples"},{"type":"function","title":"Attributes - Lume.Components.DropdownMenu.menu_item/1","doc":"* `variant` (`:atom`) - Defaults to `:default`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* `icon` (`:string`) - Defaults to `nil`.\n* `size` (`:atom`) - Defaults to `:md`.\n* `class` (`:string`) - Defaults to `nil`.\n* `href` (`:string`) - Defaults to `nil`.\n* `navigate` (`:string`) - Defaults to `nil`.\n* `patch` (`:string`) - Defaults to `nil`.\n* `replace` (`:boolean`) - Defaults to `false`.\n* `method` (`:string`) - Defaults to `nil`.\n* `csrf_token` (`:any`) - Defaults to `true`.\n* Global attributes are accepted.","ref":"Lume.Components.DropdownMenu.html#menu_item/1-attributes"},{"type":"function","title":"Slots - Lume.Components.DropdownMenu.menu_item/1","doc":"* `inner_block` (required)\n* `right_content`","ref":"Lume.Components.DropdownMenu.html#menu_item/1-slots"},{"type":"function","title":"Lume.Components.DropdownMenu.show_menu/1","doc":"Shows the dropdown menu.","ref":"Lume.Components.DropdownMenu.html#show_menu/1"},{"type":"function","title":"Lume.Components.DropdownMenu.toggle_menu/1","doc":"Toggles the visibility of the dropdown menu.","ref":"Lume.Components.DropdownMenu.html#toggle_menu/1"},{"type":"module","title":"Lume.Components.Icon","doc":"Renders a [Heroicon](https://heroicons.com).\n\nOriginally from https://github.com/phoenixframework/phoenix\n\nHeroicons come in three styles – outline, solid, and mini.\nBy default, the outline style is used, but solid and mini may\nbe applied by using the `-solid` and `-mini` suffix.\n\nYou can customize the size and colors of the icons by setting\nwidth, height, and background color classes.\n\nIcons are extracted from the `deps/heroicons` directory and bundled within\nyour compiled app.css by the plugin in your `assets/tailwind.config.js`.","ref":"Lume.Components.Icon.html"},{"type":"module","title":"Examples - Lume.Components.Icon","doc":"<.icon name=\"hero-x-mark-solid\" />\n    <.icon name=\"hero-arrow-path\" class=\"ml-1 w-3 h-3 motion-safe:animate-spin\" />","ref":"Lume.Components.Icon.html#module-examples"},{"type":"function","title":"Lume.Components.Icon.icon/1","doc":"This is copied from the default CoreComponents.icon/1 but enhanced to handle both string and list classes","ref":"Lume.Components.Icon.html#icon/1"},{"type":"function","title":"Attributes - Lume.Components.Icon.icon/1","doc":"* `name` (`:string`) (required)\n* `class` (`:any`) - Defaults to `nil`.","ref":"Lume.Components.Icon.html#icon/1-attributes"},{"type":"module","title":"Lume.Components.Navbar","doc":"A flexible navigation bar component for application headers.","ref":"Lume.Components.Navbar.html"},{"type":"module","title":"Features - Lume.Components.Navbar","doc":"* Responsive design with mobile menu toggle\n  * Customizable heading\n  * Flexible right-side content through slots\n  * Mobile-friendly with sidebar integration\n  * Dark mode support","ref":"Lume.Components.Navbar.html#module-features"},{"type":"module","title":"Examples - Lume.Components.Navbar","doc":"# Basic navbar with heading\n    <.navbar>\n      Dashboard\n    </.navbar>\n\n    # With notifications icon and user profile\n    <.navbar>\n      Settings\n      <:right_content>\n         \n          <.icon_button icon=\"hero-bell\" />\n          <.user_profile user={@current_user} />\n         \n      </:right_content>\n    </.navbar>\n\n    # Simple navbar with custom content\n    <.navbar>\n      Projects\n      <:right_content>\n        <.button>New Project</.button>\n      </:right_content>\n    </.navbar>","ref":"Lume.Components.Navbar.html#module-examples"},{"type":"function","title":"Lume.Components.Navbar.navbar/1","doc":"Renders a navigation bar component.","ref":"Lume.Components.Navbar.html#navbar/1"},{"type":"function","title":"Attributes - Lume.Components.Navbar.navbar/1","doc":"* `sidebar_id` - ID of the sidebar to toggle on mobile, defaults to \"sidebar\"\n  * `menu_toggle` - Whether to show the menu toggle button, defaults to true","ref":"Lume.Components.Navbar.html#navbar/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Navbar.navbar/1","doc":"* `inner_block` - The content to be displayed in the main section of the navbar\n  * `right_content` - Content to display on the right side of the navbar","ref":"Lume.Components.Navbar.html#navbar/1-slots"},{"type":"function","title":"Attributes - Lume.Components.Navbar.navbar/1","doc":"* `sidebar_id` (`:string`) - Defaults to `\"sidebar\"`.\n* `menu_toggle` (`:boolean`) - Defaults to `true`.","ref":"Lume.Components.Navbar.html#navbar/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Navbar.navbar/1","doc":"* `inner_block` (required)\n* `right_content`","ref":"Lume.Components.Navbar.html#navbar/1-slots"},{"type":"module","title":"Lume.Components.Separator","doc":"A simple separator line component.","ref":"Lume.Components.Separator.html"},{"type":"function","title":"Lume.Components.Separator.separator/1","doc":"Renders a separator line.","ref":"Lume.Components.Separator.html#separator/1"},{"type":"function","title":"Attributes - Lume.Components.Separator.separator/1","doc":"* `class` - Additional CSS classes to apply to the separator","ref":"Lume.Components.Separator.html#separator/1-attributes"},{"type":"function","title":"Attributes - Lume.Components.Separator.separator/1","doc":"* `class` (`:string`) - Defaults to `nil`.","ref":"Lume.Components.Separator.html#separator/1-attributes"},{"type":"module","title":"Lume.Components.Sidebar","doc":"A responsive sidebar component for application navigation.","ref":"Lume.Components.Sidebar.html"},{"type":"module","title":"Features - Lume.Components.Sidebar","doc":"* Responsive design with mobile and desktop layouts\n  * Smooth mobile transitions with backdrop\n  * Customizable content through slots\n  * Support for logo and title\n  * Dark mode support","ref":"Lume.Components.Sidebar.html#module-features"},{"type":"module","title":"Examples - Lume.Components.Sidebar","doc":"# Basic sidebar with branding and navigation\n    <.sidebar>\n      <.brand title=\"My App\" logo=\"/images/logo.svg\" />\n      <.nav_items\n        items={[\n          %{icon: \"hero-home\", label: \"Dashboard\", path: \"/\", nav_item: :dashboard},\n          %{icon: \"hero-users\", label: \"Users\", path: \"/users\", nav_item: :users},\n          %{separator: true},\n          %{icon: \"hero-cog\", label: \"Settings\", path: \"/settings\", nav_item: :settings}\n        ]}\n        current_item={:dashboard}\n      />\n    </.sidebar>\n\n    # Sidebar with custom content\n    <.sidebar id=\"admin-sidebar\">\n      <.brand title=\"MyApp Admin Panel\" />\n      <.separator />\n       \n         Custom Content \n         Add any content here! \n       \n    </.sidebar>\n\n    # Sidebar with bottom content\n    <.sidebar id=\"admin-sidebar\">\n      <.brand title=\"MyApp Admin Panel\" />\n      <.separator />\n       \n         Custom Content \n         Add any content here! \n       \n      <.separator />\n      <.bottom_content>\n         Custom bottom content \n      </.bottom_content>\n    </.sidebar>","ref":"Lume.Components.Sidebar.html#module-examples"},{"type":"function","title":"Lume.Components.Sidebar.brand/1","doc":"Renders the branding section of the sidebar.","ref":"Lume.Components.Sidebar.html#brand/1"},{"type":"function","title":"Attributes - Lume.Components.Sidebar.brand/1","doc":"* `title` - Optional title text to display at the top\n  * `logo` - Optional path to logo image\n  * `class` - Additional CSS classes to apply to the branding section","ref":"Lume.Components.Sidebar.html#brand/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Sidebar.brand/1","doc":"* `inner_block` - The content to be displayed below the title","ref":"Lume.Components.Sidebar.html#brand/1-slots"},{"type":"function","title":"Attributes - Lume.Components.Sidebar.brand/1","doc":"* `title` (`:string`) - Defaults to `nil`.\n* `logo` (`:string`) - Defaults to `nil`.\n* `class` (`:string`) - Defaults to `nil`.","ref":"Lume.Components.Sidebar.html#brand/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Sidebar.brand/1","doc":"* `inner_block`","ref":"Lume.Components.Sidebar.html#brand/1-slots"},{"type":"function","title":"Lume.Components.Sidebar.nav_items/1","doc":"Navigation items component for the sidebar.","ref":"Lume.Components.Sidebar.html#nav_items/1"},{"type":"function","title":"Attributes - Lume.Components.Sidebar.nav_items/1","doc":"* `items` - List of navigation item maps with the following structure:\n      * `icon` - Icon name (for heroicons, use \"hero-*\")\n      * `label` - Display text\n      * `path` - Navigation path\n      * `method` - HTTP method for the navigation link (e.g., \"get\", \"post\")\n      * `nav_item` - Atom identifier\n      * `separator` - Boolean to render a separator instead of a nav item\n  * `current_item` - Atom identifying the current navigation item","ref":"Lume.Components.Sidebar.html#nav_items/1-attributes"},{"type":"function","title":"Attributes - Lume.Components.Sidebar.nav_items/1","doc":"* `items` (`:list`) (required)\n* `current_item` (`:atom`) (required)","ref":"Lume.Components.Sidebar.html#nav_items/1-attributes"},{"type":"function","title":"Lume.Components.Sidebar.sidebar/1","doc":"Renders the main sidebar component.","ref":"Lume.Components.Sidebar.html#sidebar/1"},{"type":"function","title":"Attributes - Lume.Components.Sidebar.sidebar/1","doc":"* `id` - Optional unique identifier for the sidebar, defaults to \"sidebar\"\n  * `desktop_hidden` - Optional boolean to hide the sidebar on desktop view while keeping mobile functionality, defaults to false","ref":"Lume.Components.Sidebar.html#sidebar/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Sidebar.sidebar/1","doc":"* `inner_block` - The content to be displayed in the sidebar\n  * `bottom_content` - Content to be displayed at the bottom of the sidebar","ref":"Lume.Components.Sidebar.html#sidebar/1-slots"},{"type":"function","title":"Attributes - Lume.Components.Sidebar.sidebar/1","doc":"* `id` (`:string`) - Defaults to `\"sidebar\"`.\n* `desktop_hidden` (`:boolean`) - Optional boolean to hide the sidebar on desktop view while keeping mobile functionality. Defaults to `false`.","ref":"Lume.Components.Sidebar.html#sidebar/1-attributes"},{"type":"function","title":"Slots - Lume.Components.Sidebar.sidebar/1","doc":"* `inner_block` (required)\n* `bottom_content` - Content to be displayed at the bottom of the sidebar.","ref":"Lume.Components.Sidebar.html#sidebar/1-slots"},{"type":"module","title":"Lume.CoreComponents","doc":"Provides core UI components.\n\nThis is taken from the default CoreComponents module in Phoenix LiveView\n[https://github.com/phoenixframework/phoenix/]\nbut updated to add dark mode support.\n\nicon has been removed and replaced with a separate component, Lume.Components.Icon","ref":"Lume.CoreComponents.html"},{"type":"function","title":"Lume.CoreComponents.back/1","doc":"Renders a back navigation link.","ref":"Lume.CoreComponents.html#back/1"},{"type":"function","title":"Examples - Lume.CoreComponents.back/1","doc":"<.back navigate={~p\"/posts\"}>Back to posts</.back>","ref":"Lume.CoreComponents.html#back/1-examples"},{"type":"function","title":"Attributes - Lume.CoreComponents.back/1","doc":"* `navigate` (`:any`) (required)","ref":"Lume.CoreComponents.html#back/1-attributes"},{"type":"function","title":"Slots - Lume.CoreComponents.back/1","doc":"* `inner_block` (required)","ref":"Lume.CoreComponents.html#back/1-slots"},{"type":"function","title":"Lume.CoreComponents.error/1","doc":"Generates a generic error message.","ref":"Lume.CoreComponents.html#error/1"},{"type":"function","title":"Slots - Lume.CoreComponents.error/1","doc":"* `inner_block` (required)","ref":"Lume.CoreComponents.html#error/1-slots"},{"type":"function","title":"Lume.CoreComponents.flash/1","doc":"Renders flash notices.","ref":"Lume.CoreComponents.html#flash/1"},{"type":"function","title":"Examples - Lume.CoreComponents.flash/1","doc":"<.flash kind={:info} flash={@flash} />\n    <.flash kind={:info} phx-mounted={show(\"#flash\")}>Welcome Back!</.flash>","ref":"Lume.CoreComponents.html#flash/1-examples"},{"type":"function","title":"Attributes - Lume.CoreComponents.flash/1","doc":"* `id` (`:string`) - the optional id of flash container.\n* `flash` (`:map`) - the map of flash messages to display. Defaults to `%{}`.\n* `title` (`:string`) - Defaults to `nil`.\n* `kind` (`:atom`) - used for styling and flash lookup.Must be one of `:info`, or `:error`.\n* Global attributes are accepted. the arbitrary HTML attributes to add to the flash container.","ref":"Lume.CoreComponents.html#flash/1-attributes"},{"type":"function","title":"Slots - Lume.CoreComponents.flash/1","doc":"* `inner_block` - the optional inner block that renders the flash message.","ref":"Lume.CoreComponents.html#flash/1-slots"},{"type":"function","title":"Lume.CoreComponents.flash_group/1","doc":"Shows the flash group with standard titles and content.","ref":"Lume.CoreComponents.html#flash_group/1"},{"type":"function","title":"Examples - Lume.CoreComponents.flash_group/1","doc":"<.flash_group flash={@flash} />","ref":"Lume.CoreComponents.html#flash_group/1-examples"},{"type":"function","title":"Attributes - Lume.CoreComponents.flash_group/1","doc":"* `flash` (`:map`) (required) - the map of flash messages.\n* `id` (`:string`) - the optional id of flash container. Defaults to `\"flash-group\"`.","ref":"Lume.CoreComponents.html#flash_group/1-attributes"},{"type":"function","title":"Lume.CoreComponents.header/1","doc":"Renders a header with title.","ref":"Lume.CoreComponents.html#header/1"},{"type":"function","title":"Attributes - Lume.CoreComponents.header/1","doc":"* `class` (`:string`) - Defaults to `nil`.","ref":"Lume.CoreComponents.html#header/1-attributes"},{"type":"function","title":"Slots - Lume.CoreComponents.header/1","doc":"* `inner_block` (required)\n* `subtitle`\n* `actions`","ref":"Lume.CoreComponents.html#header/1-slots"},{"type":"function","title":"Lume.CoreComponents.hide/2","doc":"","ref":"Lume.CoreComponents.html#hide/2"},{"type":"function","title":"Lume.CoreComponents.hide_modal/2","doc":"","ref":"Lume.CoreComponents.html#hide_modal/2"},{"type":"function","title":"Lume.CoreComponents.input/1","doc":"Renders an input with label and error messages.\n\nA `Phoenix.HTML.FormField` may be passed as argument,\nwhich is used to retrieve the input name, id, and values.\nOtherwise all attributes may be passed explicitly.","ref":"Lume.CoreComponents.html#input/1"},{"type":"function","title":"Types - Lume.CoreComponents.input/1","doc":"This function accepts all HTML input types, considering that:\n\n  * You may also set `type=\"select\"` to render a ` ` tag\n\n  * `type=\"checkbox\"` is used exclusively to render boolean values\n\n  * For live file uploads, see `Phoenix.Component.live_file_input/1`\n\nSee https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input\nfor more information. Unsupported types, such as hidden and radio,\nare best written directly in your templates.","ref":"Lume.CoreComponents.html#input/1-types"},{"type":"function","title":"Examples - Lume.CoreComponents.input/1","doc":"<.input field={@form[:email]} type=\"email\" />\n    <.input name=\"my-input\" errors={[\"oh no!\"]} />","ref":"Lume.CoreComponents.html#input/1-examples"},{"type":"function","title":"Attributes - Lume.CoreComponents.input/1","doc":"* `id` (`:any`) - Defaults to `nil`.\n* `name` (`:any`)\n* `label` (`:string`) - Defaults to `nil`.\n* `value` (`:any`)\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].\n* `errors` (`:list`) - Defaults to `[]`.\n* `checked` (`:boolean`) - the checked flag for checkbox inputs.\n* `prompt` (`:string`) - the prompt for select inputs. Defaults to `nil`.\n* `options` (`:list`) - the options to pass to Phoenix.HTML.Form.options_for_select/2.\n* `multiple` (`:boolean`) - the multiple flag for select inputs. Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"accept\", \"autocomplete\", \"capture\", \"cols\", \"disabled\", \"form\", \"list\", \"max\", \"maxlength\", \"min\", \"minlength\", \"multiple\", \"pattern\", \"placeholder\", \"readonly\", \"required\", \"rows\", \"size\", \"step\"]`.","ref":"Lume.CoreComponents.html#input/1-attributes"},{"type":"function","title":"Lume.CoreComponents.label/1","doc":"Renders a label.","ref":"Lume.CoreComponents.html#label/1"},{"type":"function","title":"Attributes - Lume.CoreComponents.label/1","doc":"* `for` (`:string`) - Defaults to `nil`.","ref":"Lume.CoreComponents.html#label/1-attributes"},{"type":"function","title":"Slots - Lume.CoreComponents.label/1","doc":"* `inner_block` (required)","ref":"Lume.CoreComponents.html#label/1-slots"},{"type":"function","title":"Lume.CoreComponents.list/1","doc":"Renders a data list.","ref":"Lume.CoreComponents.html#list/1"},{"type":"function","title":"Examples - Lume.CoreComponents.list/1","doc":"<.list>\n      <:item title=\"Title\">{@post.title}</:item>\n      <:item title=\"Views\">{@post.views}</:item>\n    </.list>","ref":"Lume.CoreComponents.html#list/1-examples"},{"type":"function","title":"Slots - Lume.CoreComponents.list/1","doc":"* `item` (required) - Accepts attributes:\n\n  * `title` (`:string`) (required)","ref":"Lume.CoreComponents.html#list/1-slots"},{"type":"function","title":"Lume.CoreComponents.modal/1","doc":"Renders a modal.","ref":"Lume.CoreComponents.html#modal/1"},{"type":"function","title":"Examples - Lume.CoreComponents.modal/1","doc":"<.modal id=\"confirm-modal\">\n      This is a modal.\n    </.modal>\n\nJS commands may be passed to the `:on_cancel` to configure\nthe closing/cancel event, for example:\n\n    <.modal id=\"confirm\" on_cancel={JS.navigate(~p\"/posts\")}>\n      This is another modal.\n    </.modal>","ref":"Lume.CoreComponents.html#modal/1-examples"},{"type":"function","title":"Attributes - Lume.CoreComponents.modal/1","doc":"* `id` (`:string`) (required)\n* `show` (`:boolean`) - Defaults to `false`.\n* `on_cancel` (`Phoenix.LiveView.JS`) - Defaults to `%Phoenix.LiveView.JS{ops: []}`.","ref":"Lume.CoreComponents.html#modal/1-attributes"},{"type":"function","title":"Slots - Lume.CoreComponents.modal/1","doc":"* `inner_block` (required)","ref":"Lume.CoreComponents.html#modal/1-slots"},{"type":"function","title":"Lume.CoreComponents.show/2","doc":"","ref":"Lume.CoreComponents.html#show/2"},{"type":"function","title":"Lume.CoreComponents.show_modal/2","doc":"","ref":"Lume.CoreComponents.html#show_modal/2"},{"type":"function","title":"Lume.CoreComponents.simple_form/1","doc":"Renders a simple form.","ref":"Lume.CoreComponents.html#simple_form/1"},{"type":"function","title":"Examples - Lume.CoreComponents.simple_form/1","doc":"<.simple_form for={@form} phx-change=\"validate\" phx-submit=\"save\">\n      <.input field={@form[:email]} label=\"Email\"/>\n      <.input field={@form[:username]} label=\"Username\" />\n      <:actions>\n        <.button>Save</.button>\n      </:actions>\n    </.simple_form>","ref":"Lume.CoreComponents.html#simple_form/1-examples"},{"type":"function","title":"Attributes - Lume.CoreComponents.simple_form/1","doc":"* `for` (`:any`) (required) - the data structure for the form.\n* `as` (`:any`) - the server side parameter to collect all input under. Defaults to `nil`.\n* Global attributes are accepted. the arbitrary HTML attributes to apply to the form tag. Supports all globals plus: `[\"autocomplete\", \"name\", \"rel\", \"action\", \"enctype\", \"method\", \"novalidate\", \"target\", \"multipart\"]`.","ref":"Lume.CoreComponents.html#simple_form/1-attributes"},{"type":"function","title":"Slots - Lume.CoreComponents.simple_form/1","doc":"* `inner_block` (required)\n* `actions` - the slot for form actions, such as a submit button.","ref":"Lume.CoreComponents.html#simple_form/1-slots"},{"type":"function","title":"Lume.CoreComponents.table/1","doc":"Renders a table with generic styling.","ref":"Lume.CoreComponents.html#table/1"},{"type":"function","title":"Examples - Lume.CoreComponents.table/1","doc":"<.table id=\"users\" rows={@users}>\n      <:col :let={user} label=\"id\">{user.id}</:col>\n      <:col :let={user} label=\"username\">{user.username}</:col>\n    </.table>","ref":"Lume.CoreComponents.html#table/1-examples"},{"type":"function","title":"Attributes - Lume.CoreComponents.table/1","doc":"* `id` (`:string`) (required)\n* `rows` (`:list`) (required)\n* `row_id` (`:any`) - the function for generating the row id. Defaults to `nil`.\n* `row_click` (`:any`) - the function for handling phx-click on each row. Defaults to `nil`.\n* `row_item` (`:any`) - the function for mapping each row before calling the :col and :action slots. Defaults to `&Function.identity/1`.","ref":"Lume.CoreComponents.html#table/1-attributes"},{"type":"function","title":"Slots - Lume.CoreComponents.table/1","doc":"* `col` (required) - Accepts attributes:\n\n  * `label` (`:string`)\n* `action` - the slot for showing user actions in the last table column.","ref":"Lume.CoreComponents.html#table/1-slots"},{"type":"function","title":"Lume.CoreComponents.translate_error/1","doc":"Translates an error message using gettext.","ref":"Lume.CoreComponents.html#translate_error/1"},{"type":"function","title":"Lume.CoreComponents.translate_errors/2","doc":"Translates the errors for a field from a keyword list of errors.","ref":"Lume.CoreComponents.html#translate_errors/2"},{"type":"module","title":"Lume.Gettext","doc":"Default Gettext module for Lume.\n\nApplications using Lume can override this by setting their own Gettext backend\nin their config:\n\n    config :lume,\n      gettext_backend: MyApp.Gettext","ref":"Lume.Gettext.html"},{"type":"function","title":"Lume.Gettext.handle_missing_bindings/2","doc":"","ref":"Lume.Gettext.html#handle_missing_bindings/2"},{"type":"function","title":"Lume.Gettext.handle_missing_plural_translation/7","doc":"","ref":"Lume.Gettext.html#handle_missing_plural_translation/7"},{"type":"function","title":"Lume.Gettext.handle_missing_translation/5","doc":"","ref":"Lume.Gettext.html#handle_missing_translation/5"},{"type":"extras","title":"Lume UI","doc":"# Lume UI\n\nLume is a simple UI component library for Phoenix LiveView applications. It provides a set of ready-to-use components for your Phoenix LiveView applications.\n\nI got fed-up of reinventing the wheel every time I started a new project, and I don't want to always rely on paid UI libraries, so I decided to extract some of the components that I have created from my previous projects into a library.\n\nI also wanted to fit into 'Vanilla LiveView', and use the existing CoreComponents interface. So one of the primary goals of Lume is to be lightweight, easy to use, customize, and extend.\n\nIt is still in the early stages of development and currently only provides a handful of components, but I hope to add many more over time.\n\nPlease take a look at [lume_example](https://github.com/abradburne/lume_example) for an example how to use the components to create an application using a sidebar navigation menu.","ref":"readme.html"},{"type":"extras","title":"Features - Lume UI","doc":"- Modern, clean design with dark mode support\n- Built for Phoenix LiveView\n- Simple navigation layout\n- Responsive layouts\n- Customizable with Tailwind CSS","ref":"readme.html#features"},{"type":"extras","title":"Components - Lume UI","doc":"","ref":"readme.html#components"},{"type":"extras","title":"Avatar - Lume UI","doc":"A component for displaying user avatars, including fallback options for when an image is not available.","ref":"readme.html#avatar"},{"type":"extras","title":"Breadcrumbs - Lume UI","doc":"A component for displaying navigation breadcrumbs with customizable separators and sizes. Ideal for showing the user's current location in hierarchical navigation structures.","ref":"readme.html#breadcrumbs"},{"type":"extras","title":"Badge - Lume UI","doc":"A component for displaying small notifications or status indicators, often used for alerts or counts.","ref":"readme.html#badge"},{"type":"extras","title":"Button - Lume UI","doc":"A versatile button component with multiple variants and sizes.","ref":"readme.html#button"},{"type":"extras","title":"DropdownMenu - Lume UI","doc":"A flexible dropdown menu component that supports various triggers and menu items, including icons and variants.","ref":"readme.html#dropdownmenu"},{"type":"extras","title":"Navbar - Lume UI","doc":"A navigation bar component that can include links and other interactive elements for site navigation.","ref":"readme.html#navbar"},{"type":"extras","title":"Separator - Lume UI","doc":"A component used to visually separate content, typically used in lists or menus.","ref":"readme.html#separator"},{"type":"extras","title":"Sidebar - Lume UI","doc":"A component for creating a sidebar navigation menu, which can contain links and other interactive elements.","ref":"readme.html#sidebar"},{"type":"extras","title":"Installation - Lume UI","doc":"1. Add Lume to your mix.exs dependencies:\n\n```elixir\ndef deps do\n  [\n    {:lume, \"~> 0.2.0\"}\n  ]\nend\n```\n\n2. Run mix deps.get to install:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Setup - Lume UI","doc":"","ref":"readme.html#setup"},{"type":"extras","title":"1. Configure Tailwind - Lume UI","doc":"Lume components use Tailwind CSS for styling. You need to configure your application's `tailwind.config.js` to include Lume's component paths so they don't get purged by Tailwind:\n\n```javascript\n// assets/tailwind.config.js\nmodule.exports = {\n  content: [\n    \"./js/**/*.js\",\n    \"../lib/*_web/**/*.*ex\",\n    \"../lib/*_web/**/*.heex\",\n    \"../deps/lume/**/*.*ex\"  // Add this line to include Lume components\n  ],\n  // ... rest of your config\n}\n```","ref":"readme.html#1-configure-tailwind"},{"type":"extras","title":"2. Configure Gettext - Lume UI","doc":"Lume components use Gettext for internationalization. To manage translations in your application, configure Lume to use your application's Gettext backend:\n\n```elixir\n# In your config/config.exs\nconfig :lume,\n  gettext_backend: MyAppWeb.Gettext\n```\n\nThis allows you to manage all translations, including Lume's UI strings, in your application's `priv/gettext` directory.","ref":"readme.html#2-configure-gettext"},{"type":"extras","title":"3. Setup Components - Lume UI","doc":"Lume has its' own CoreComponents module, adding dark mode support and other tweaks to fit in with the Lume design and functionality. We will keep CoreComponents up to date with any changes made in Phoenix's CoreComponents module.\n\nIn your `lib/my_app_web.ex` module, delete the existing `CoreComponents` module and replace it with the Lume components in the html_helpers setup as shown below, along with the Lume components module:\n\n```elixir\ndefmodule MyAppWeb do\n  # ...\n\n  defp html_helpers do\n    quote do\n      use Lume  # This imports all Lume components\n\n      # Replace existing Core UI components with Lume equivalents\n      import Lume.CoreComponents\n\n      # ... rest of your html_helpers setup\n    end\n  end\nend\n```","ref":"readme.html#3-setup-components"},{"type":"extras","title":"4. Customizing Sidebar Navigation (optional) - Lume UI","doc":"Lume provides a simple sidebar navigation system that you can customize by providing your own navigation module. Here's how to set it up:\n\n1. Create a navigation module in your application (e.g. `lib/my_app_web/navigation.ex`):\n\n```elixir\ndefmodule MyAppWeb.Navigation do\n  @default_items [\n    # Basic navigation item\n    %{icon: \"hero-home\", label: \"Dashboard\", nav_item: :dashboard, navigate: \"/\"},\n\n    # Add a separator between groups\n    %{separator: true},\n\n    # Another navigation group\n    %{icon: \"hero-users\", label: \"Users\", nav_item: :users, navigate: \"/users\"},\n    %{icon: \"hero-cog\", label: \"Settings\", nav_item: :settings, navigate: \"/settings\"}\n  ]\n\n  def default_items do\n    @default_items\n  end\nend\n```\n\n2. In your LiveViews, set the current navigation item:\n\n```elixir\ndefmodule MyAppWeb.UsersLive do\n  use MyAppWeb, :live_view\n\n  def mount(_params, _session, socket) do\n    socket = assign(socket, :current_item, :users)\n    {:ok, socket}\n  end\nend\n```\n\nYou can then pass the navigation items and the current item into the sidebar's `nav_items` component to display the navigation list.\n\n3. Customize the sidebar appearance:\n\nYou can use the `brand` and `nav_items` components to add a header and navigation items to the sidebar, for example:\n\n```heex\n# Basic sidebar with navigation\n<.sidebar>\n  <.brand title=\"My App\" logo=\"/images/logo.svg\" />\n  <.nav_items\n    items={MyAppWeb.Navigation.default_items()}\n    current_item={@current_item}\n  />\n</.sidebar>\n```\n\nYou can also just use the `inner_block` slot to add custom content to the sidebar, for example:\n```heex\n# Sidebar with custom content\n<.sidebar id=\"admin-sidebar\" title=\"Admin Panel\">\n   \n     Custom Content \n     Add any content here! \n   \n</.sidebar>\n```\n\nThe sidebar component supports:\n- `id`: Optional unique identifier for the sidebar, defaults to \"sidebar\"\n\nThe `brand` component supports:\n- `title`: Optional text to display at the top of the sidebar\n- `logo`: Optional path to your logo image\n- `class`: Optional CSS classes to apply to the branding section\n\nThe `nav_items` component supports:\n- `current_item`: Atom representing the current navigation item\n- `items`: List of navigation items, where each item can be:\n  - Regular item: `%{icon: \"hero-*\", label: \"Label\", nav_item: :atom, navigate: \"/path\"}` or\n  - Regular item: `%{icon: \"hero-*\", label: \"Label\", nav_item: :atom, href: \"/path\", method: \"delete\"}`\n  - Separator: `%{separator: true}` to add a visual divider between groups\n\nBy default, the sidebar is 72px wide on desktop. To accommodate it, set the left padding of your main content container to 72px.","ref":"readme.html#4-customizing-sidebar-navigation-optional"},{"type":"extras","title":"Usage - Lume UI","doc":"Lume provides several components out of the box:\n\n- `<.avatar>` - A versatile avatar component with image support and fallback initials\n- `<.badge>` - A flexible badge component for status indicators and labels\n- `<.breadcrumb>` - A simple breadcrumb component\n- `<.button>` - A versatile button component with multiple variants and sizes\n- `<.dropdown_menu>` - A flexible dropdown menu component\n- `<.navbar>` - A top navigation bar\n- `<.separator>` - A simple separator component\n- `<.sidebar>` - A responsive sidebar with navigation\n- More components coming soon...","ref":"readme.html#usage"},{"type":"extras","title":"Examples - Lume UI","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Avatar Component - Lume UI","doc":"The avatar component supports images with fallback initials, multiple sizes, and status indicators:\n\n```heex\n# Basic avatar with image\n<.avatar\n  alt=\"John Doe\"\n  fallback=\"JD\"\n  image_url=\"/images/john.jpg\"\n/>\n\n# Avatar with status indicator\n<.avatar\n  alt=\"Alan B\"\n  fallback=\"AB\"\n  show_dot\n  dot_variant={:success}\n/>\n\n# Custom size and shape\n<.avatar\n  alt=\"User\"\n  fallback=\"U\"\n  size={:lg}\n  shape={:square}\n/>\n```","ref":"readme.html#avatar-component"},{"type":"extras","title":"Button Component - Lume UI","doc":"The button component supports multiple variants, sizes, and styling options:\n\n```heex\n# Basic button\n<.button>Send!</.button>\n\n# Button with Phoenix event\n<.button phx-click=\"go\" class=\"ml-2\">Send!</.button>\n\n# Button with leading icon\n<.button icon=\"hero-user-group\">Teams</.button>\n\n# Outline button without border\n<.button variant=\"outline\" border={false}>Borderless</.button>\n\n# Left-aligned full-width button\n<.button justify=\"start\" class=\"w-full\">Left aligned</.button>\n\n# Large secondary button\n<.button variant=\"secondary\" size=\"lg\">Large Button</.button>\n```\n\n#### Button Component Properties\n\n- `type`: HTML button type attribute, defaults to \"button\"\n- `class`: Additional CSS classes to apply to the button\n- `variant`: Button style variant (\"primary\", \"secondary\", \"outline\", \"minimal\"), defaults to \"primary\"\n- `size`: Size variant (\"xs\", \"sm\", \"md\", \"lg\", \"xl\"), defaults to \"md\"\n- `icon`: Optional icon name (from heroicons)\n- `justify`: Content alignment (\"start\", \"center\", \"end\"), defaults to \"center\"\n- `border`: Whether to show a border (only applies to outline variant), defaults to true","ref":"readme.html#button-component"},{"type":"extras","title":"Badge Component - Lume UI","doc":"The badge component is perfect for status indicators, labels, and counts:\n\n```heex\n# Basic badge\n<.badge>Default</.badge>\n\n# Status badge with icon\n<.badge variant={:success} icon=\"hero-check-circle\">\n  Active\n</.badge>\n\n# Warning badge with dot\n<.badge variant={:warning} show_dot>\n  Pending\n</.badge>\n\n# Custom styled badge\n<.badge\n  variant={:primary}\n  size={:lg}\n  shape={:flat}\n  bordered\n>\n  Featured\n</.badge>\n```","ref":"readme.html#badge-component"},{"type":"extras","title":"Breadcrumb Component - Lume UI","doc":"The breadcrumb component is a flexible breadcrumb navigation component that supports custom paths and labels:\n\n```elixir\n<.breadcrumbs id=\"navigation\">\n  <:crumb navigate={~p\"/\"}>\n    <.icon name=\"hero-home-mini\" class=\"w-4 h-4 mr-1\" /> Home\n  </:crumb>\n  <:crumb navigate={~p\"/items\"}>Items</:crumb>\n  <:crumb current={true}>Current Item</:crumb>\n</.breadcrumbs>\n```\n\nThe breadcrumbs component is designed to be highly customizable while maintaining accessibility and consistent styling. Each crumb can be a link or plain text, and you can include icons or other content within crumbs.\n\n#### Component Properties\n\n- `id`: Required string identifier for the breadcrumbs component\n- `class`: Optional CSS classes to apply to the container\n- `separator_icon`: Optional icon name for the separator (default: \"hero-chevron-right-mini\")\n- `size`: Optional size variant (\"xs\", \"sm\", \"md\", \"lg\", default: \"sm\")\n\n#### Crumb Slots\n\nEach crumb is defined using the `:crumb` slot and supports:\n- `navigate`: Optional path for making the crumb a clickable link\n- `current`: Optional boolean to mark the current/active crumb (adds appropriate styling and aria-current)\n\n#### Size Variants\n\nThe breadcrumbs component supports four size variants that affect both text and separator icons:\n```elixir\n<.breadcrumbs id=\"xs-example\" size=\"xs\">\n  <:crumb navigate={~p\"/\"}>Home</:crumb>\n  <:crumb>Items</:crumb>\n</.breadcrumbs>\n\n<.breadcrumbs id=\"lg-example\" size=\"lg\">\n  <:crumb navigate={~p\"/\"}>Home</:crumb>\n  <:crumb>Items</:crumb>\n</.breadcrumbs>\n```\n\n#### Custom Separators\n\nYou can customize the separator icon using any icon from the Hero Icons set:\n```elixir\n<.breadcrumbs id=\"custom\" separator_icon=\"hero-chevron-double-right-mini\">\n  <:crumb navigate={~p\"/\"}>Home</:crumb>\n  <:crumb>Items</:crumb>\n</.breadcrumbs>\n```","ref":"readme.html#breadcrumb-component"},{"type":"extras","title":"Dropdown Menu - Lume UI","doc":"The DropdownMenu component allows you to create flexible dropdown menus with various triggers and menu items.\n\n#### Basic Usage\n\n```elixir\n<.dropdown_menu id=\"user-menu\">\n  <:trigger>\n     Options \n  </:trigger>\n  <.menu_item>\n    <.link navigate={~p\"/profile\"} class=\"w-full\">Profile</.link>\n  </.menu_item>\n  <.menu_item>\n    <.link patch={~p\"/settings\"} class=\"w-full\">Settings</.link>\n  </.menu_item>\n  <.menu_item variant={:error}>\n     Sign out \n  </.menu_item>\n</.dropdown_menu>\n```\n\n#### With Icons\n\nYou can also add icons to your menu items:\n\n```elixir\n<.dropdown_menu id=\"icon-menu\">\n  <:trigger>\n     Menu \n  </:trigger>\n\n  <.menu_item icon=\"hero-user\">\n    <.link navigate={~p\"/profile\"} class=\"w-full\">Profile</.link>\n  </.menu_item>\n\n  <.menu_item icon=\"hero-cog-6-tooth\">\n    <.link navigate={~p\"/settings\"} class=\"w-full\">Settings</.link>\n  </.menu_item>\n\n  <.separator />\n\n  <.menu_item variant={:error} icon=\"hero-arrow-right-on-rectangle\">\n     Sign out \n  </.menu_item>\n</.dropdown_menu>\n```\n\n#### Custom Alignment\n\nYou can customize the alignment of the dropdown menu:\n\n```elixir\n<.dropdown_menu id=\"right-aligned-menu\" align={:right}>\n  <:trigger>\n     Menu \n  </:trigger>\n  <.menu_item>\n    Profile\n  </.menu_item>\n</.dropdown_menu>\n```\n\n#### Size Variants\n\nThe DropdownMenu supports different size variants:\n\n```elixir\n<.dropdown_menu id=\"large-menu\" size={:lg}>\n  <:trigger>\n     Large Menu \n  </:trigger>\n  <.menu_item>\n    Item 1\n  </.menu_item>\n</.dropdown_menu>\n```\n\n#### Disabled Menu Items\n\nYou can disable menu items as well:\n\n```elixir\n<.dropdown_menu id=\"disabled-item-menu\">\n  <:trigger>\n     Menu \n  </:trigger>\n  <.menu_item disabled={true}>\n    Disabled Item\n  </.menu_item>\n</.dropdown_menu>\n```","ref":"readme.html#dropdown-menu"},{"type":"extras","title":"Navbar Component - Lume UI","doc":"The navbar component is a flexible top navigation bar that supports responsive design and custom right-side content:\n\n```heex\n# Basic navbar with heading\n<.navbar>\n  Dashboard\n  <:right_content>\n     \n      <.icon name=\"hero-bell\" class=\"h-6 w-6\" />\n     \n  </:right_content>\n</.navbar>\n```\n\nBy default, the navbar will show a mobile menu toggle (aka 'hamburger menu') on mobile (or when the screen is too narrow),\nbut you can disable it by setting `menu_toggle` to `false`:\n\n```heex\n<.navbar menu_toggle={false}>\n  Dashboard\n  <:right_content>\n     \n      <.icon name=\"hero-bell\" class=\"h-6 w-6\" />\n     \n  </:right_content>\n</.navbar>\n```\n\nBy default, the navbar will show a mobile menu toggle (aka 'hamburger menu') on mobile (or when the screen is too narrow), but you can disable it by setting `menu_toggle` to `:false`:","ref":"readme.html#navbar-component"},{"type":"extras","title":"Separator Component - Lume UI","doc":"The separator component is a simple separator line that can be used to divide sections of a navbar:\n\n```heex\n<.separator />\n```","ref":"readme.html#separator-component"},{"type":"extras","title":"Sidebar Component - Lume UI","doc":"The sidebar component is a responsive sidebar navigation menu that supports custom branding and navigation items:\n\n```heex\n<.sidebar>\n  <.brand title=\"My App\" logo=\"/images/logo.svg\" />\n  <.nav_items\n    items={MyAppWeb.Navigation.default_items()}\n    current_item={@current_item}\n  />\n</.sidebar>\n```\n\nYou can also just use the `inner_block` slot to add custom content to the sidebar, for example:\n```heex\n# Sidebar with custom content\n<.sidebar id=\"admin-sidebar\" title=\"Admin Panel\">\n  <.brand title=\"Admin Panel\" class=\"text-primary-600\" />\n  <.separator />\n   \n     Custom Content \n     Add any content here! \n   \n</.sidebar>\n```\n\nThe sidebar component also supports a `bottom_content` slot for content that should appear at the bottom of the sidebar:\n```heex\n# Sidebar with bottom content\n<.sidebar>\n  <.brand title=\"My App\" logo=\"/images/logo.svg\" />\n  <.nav_items\n    items={MyAppWeb.Navigation.default_items()}\n    current_item={@current_item}\n  />\n\n  <:bottom_content>\n     \n        2025 My Company \n     \n  </:bottom_content>\n</.sidebar>\n```\n\nThe sidebar component supports:\n- `id`: Optional unique identifier for the sidebar, defaults to \"sidebar\"\n- `desktop_hidden`: Optional boolean to hide the sidebar on desktop view while keeping mobile functionality","ref":"readme.html#sidebar-component"},{"type":"extras","title":"Credits - Lume UI","doc":"Designed and built by [Alan Bradburne](https://alanb.dev).\nCoreComponents originally forked from [PhoenixComponents](https://github.com/phoenixframework/phoenix_components).","ref":"readme.html#credits"},{"type":"extras","title":"Copyright and License - Lume UI","doc":"Copyright (c) 2025 Alan Bradburne\n\nThis library is released under the MIT License.","ref":"readme.html#copyright-and-license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}